# Generated by roxygen2: do not edit by hand

S3method(print,cvxr_result)
export("%<<%")
export("%>>%")
export("delta<-")
export("gradient<-")
export("label<-")
export("sample_bounds<-")
export("value<-")
export(And)
export(CLARABEL_SOLVER)
export(COPT_SOLVER)
export(CPLEX_SOLVER)
export(CVXOPT_SOLVER)
export(CallbackParam)
export(Constant)
export(DIFFCP_SOLVER)
export(DiagMat)
export(DiagVec)
export(ECOS_BB_SOLVER)
export(ECOS_SOLVER)
export(Equality)
export(ExpCone)
export(FiniteSet)
export(GLPK_MI_SOLVER)
export(GLPK_SOLVER)
export(GUROBI_SOLVER)
export(HIGHS_SOLVER)
export(INFEASIBLE)
export(INFEASIBLE_INACCURATE)
export(INFEASIBLE_OR_UNBOUNDED)
export(IPOPT_SOLVER)
export(Inequality)
export(KNITRO_SOLVER)
export(MOSEK_SOLVER)
export(Maximize)
export(Minimize)
export(NonNeg)
export(NonPos)
export(Not)
export(OPTIMAL)
export(OPTIMAL_INACCURATE)
export(OSQP_SOLVER)
export(Or)
export(PIQP_SOLVER)
export(PSD)
export(Parameter)
export(PartialProblem)
export(PowCone3D)
export(PowConeND)
export(Problem)
export(SCIP_SOLVER)
export(SCS_SOLVER)
export(SOC)
export(SOLVER_ERROR)
export(SizeMetrics)
export(UNBOUNDED)
export(UNBOUNDED_INACCURATE)
export(UNO_SOLVER)
export(USER_LIMIT)
export(Variable)
export(XPRESS_SOLVER)
export(Xor)
export(Zero)
export(as_cvxr_expr)
export(available_solvers)
export(backward)
export(bmat)
export(ceil_expr)
export(condition_number)
export(constants)
export(constraints)
export(conv)
export(convolve)
export(cummax_expr)
export(cumsum_axis)
export(curvature)
export(cvar)
export(cvxr_diff)
export(cvxr_mean)
export(cvxr_norm)
export(cvxr_outer)
export(cvxr_std)
export(cvxr_var)
export(deep_flatten)
export(delta)
export(derivative)
export(diag)
export(diff_pos)
export(dist_ratio)
export(dotsort)
export(dual_value)
export(entr)
export(exclude_solvers)
export(expr_H)
export(expr_sign)
export(eye_minus_inv)
export(floor_expr)
export(format_labeled)
export(gen_lambda_max)
export(geo_mean)
export(get_bounds)
export(get_problem_data)
export(gmatmul)
export(gradient)
export(harmonic_mean)
export(hstack)
export(huber)
export(id)
export(iff)
export(implies)
export(include_solvers)
export(indicator)
export(installed_solvers)
export(inv_pos)
export(inv_prod)
export(is_affine)
export(is_atom_smooth)
export(is_concave)
export(is_constant)
export(is_convex)
export(is_dcp)
export(is_dgp)
export(is_dnlp)
export(is_dpp)
export(is_dqcp)
export(is_linearizable_concave)
export(is_linearizable_convex)
export(is_log_log_affine)
export(is_log_log_concave)
export(is_log_log_convex)
export(is_lp)
export(is_matrix)
export(is_mixed_integer)
export(is_nonneg)
export(is_nonpos)
export(is_nsd)
export(is_psd)
export(is_pwl)
export(is_qp)
export(is_quadratic)
export(is_quasiconcave)
export(is_quasiconvex)
export(is_quasilinear)
export(is_scalar)
export(is_smooth)
export(is_symmetric)
export(is_vector)
export(is_zero)
export(kl_div)
export(kron)
export(label)
export(lambda_max)
export(lambda_min)
export(lambda_sum_largest)
export(lambda_sum_smallest)
export(length_expr)
export(log1p_atom)
export(log1p_expr)
export(log_det)
export(log_normcdf)
export(log_sum_exp)
export(loggamma)
export(logistic)
export(matrix_frac)
export(matrix_trace)
export(max_elemwise)
export(max_entries)
export(min_elemwise)
export(min_entries)
export(mixed_norm)
export(multiply)
export(name)
export(neg)
export(norm)
export(norm1)
export(norm2)
export(norm_inf)
export(norm_nuc)
export(normcdf)
export(objective)
export(one_minus_pos)
export(outer)
export(p_norm)
export(param_backward)
export(param_dict)
export(param_forward)
export(param_id_map)
export(parameters)
export(partial_optimize)
export(partial_trace)
export(partial_transpose)
export(perspective)
export(pf_eigenvalue)
export(pos)
export(power)
export(problem_data)
export(problem_solution)
export(problem_status)
export(problem_unpack_results)
export(prod_entries)
export(psolve)
export(ptp)
export(quad_form)
export(quad_over_lin)
export(rel_entr)
export(reshape_expr)
export(residual)
export(resolvent)
export(sample_bounds)
export(scalar_product)
export(scalarize)
export(scalene)
export(sd)
export(set_excluded_solvers)
export(set_label)
export(sigma_max)
export(size)
export(size_metrics)
export(solution)
export(solve_via_data)
export(solver_default_param)
export(solver_opts)
export(solver_stats)
export(square)
export(status)
export(std)
export(sum_entries)
export(sum_largest)
export(sum_smallest)
export(sum_squares)
export(to_latex)
export(total_variation)
export(tr_inv)
export(tv)
export(unpack_results)
export(upper_tri)
export(value)
export(var)
export(var_backward)
export(var_dict)
export(var_forward)
export(var_id_map)
export(variables)
export(vdot)
export(vec)
export(vec_to_upper_tri)
export(violation)
export(visualize)
export(vstack)
export(xexp)
import(S7)
importFrom(Matrix,
  Diagonal,
  Matrix,
  crossprod,
  sparseMatrix,
  t,
  tcrossprod
)
importFrom(Rcpp,evalCpp)
importFrom(clarabel,clarabel_solver)
importFrom(cli,
  cli_abort,
  cli_alert_info,
  cli_alert_success,
  cli_bullets,
  cli_inform,
  cli_rule,
  cli_text,
  cli_warn
)
importFrom(gmp,
  as.bigq,
  as.bigz,
  denominator,
  is.bigq,
  is.bigz,
  numerator
)
importFrom(highs,highs_solve)
importFrom(methods,
  .hasSlot,
  as,
  is,
  show
)
importFrom(osqp,osqp)
importFrom(scs,scs)
useDynLib(CVXR, .registration = TRUE)
